@@ -1,6 +1,6 @@
 package Map::Tube::Delhi::Line::Red;
 
-$Map::Tube::Delhi::Line::Red::VERSION = '0.20';
+$Map::Tube::Delhi::Line::Red::VERSION = '0.21';
 
 =head1 NAME
 
@@ -8,45 +8,47 @@ Map::Tube::Delhi::Line::Red - Delhi Metro Red Line stations.
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =head1 DESCRIPTION
 
 Delhi Metro Red Line stations.
 
-    +------------------------------------+--------------------------------------+
-    |                                    |                                      |
-    | Station Name                       | Linked To                            |
-    |                                    |                                      |
-    +------------------------------------+--------------------------------------+
-    | Rithala                            | Rohini West                          |
-    | Rohini West                        | Rithala, Rohini East                 |
-    | Rohini East                        | Rohini West, Pitampura               |
-    | Pitampura                          | Rohini East, Kohat Enclave           |
-    | Kohat Enclave                      | Pitampura, Netaji Subhash Place      |
-    | Netaji Subhash Place               | Kohat Enclave, Keshav Puram          |
-    | Keshav Puram                       | Netaji Subhash Place, Kanhaiya Nagar |
-    | Kanhaiya Nagar                     | Keshav Puram, Inderlok               |
-    +------------------------------------+--------------------------------------+
-    | Inderlok                           | Kanhaiya Nagar, Shastri Nagar        |
-    | L<Map::Tube::Delhi::Line::Green>   |                                      |
-    +------------------------------------+--------------------------------------+
-    | Shastri Nagar                      | Inderlok, Pratap Nagar               |
-    | Pratap Nagar                       | Shastri Nagar, Pulbangsh             |
-    | Pulbangash                         | Pratap Nagar, Tis Hazari             |
-    | Tis Hazari                         | Pulbangsh, Kashmere Gate             |
-    +------------------------------------+--------------------------------------+
-    | Kashmere Gate                      | Tis Hazari, Shasri Park              |
-    | L<Map::Tube::Delhi::Line::Yellow>  |                                      |
-    +------------------------------------+--------------------------------------+
-    | Shastri Park                       | Kashmere Gate, Seelampur             |
-    | Seelampur                          | Shastri Park, Welcome                |
-    | Welcome                            | Seelampur, Shahdara                  |
-    | Shahdara                           | Welcome, Mansarovar Park             |
-    | Mansarovar Park                    | Shahdara, Jhilmil                    |
-    | Jhilmil                            | Mansarovar Park, Dishad Garden       |
-    | Dilshad Garden                     | Jhilmil                              |
-    +------------------------------------+--------------------------------------+
+    +-----------------------+--------------------------------------+
+    |                       |                                      |
+    | Station Name          | Linked To                            |
+    |                       |                                      |
+    +-----------------------+--------------------------------------+
+    | Rithala               | Rohini West                          |
+    | Rohini West           | Rithala, Rohini East                 |
+    | Rohini East           | Rohini West, Pitampura               |
+    | Pitampura             | Rohini East, Kohat Enclave           |
+    | Kohat Enclave         | Pitampura, Netaji Subhash Place      |
+    | Netaji Subhash Place  | Kohat Enclave, Keshav Puram          |
+    | Keshav Puram          | Netaji Subhash Place, Kanhaiya Nagar |
+    | Kanhaiya Nagar        | Keshav Puram, Inderlok               |
+    | Inderlok              | Kanhaiya Nagar, Shastri Nagar        |
+    | Shastri Nagar         | Inderlok, Pratap Nagar               |
+    | Pratap Nagar          | Shastri Nagar, Pulbangsh             |
+    | Pulbangash            | Pratap Nagar, Tis Hazari             |
+    | Tis Hazari            | Pulbangsh, Kashmere Gate             |
+    | Kashmere Gate         | Tis Hazari, Shastri Park             |
+    | Shastri Park          | Kashmere Gate, Seelampur             |
+    | Seelampur             | Shastri Park, Welcome                |
+    | Welcome               | Seelampur, Shahdara                  |
+    | Shahdara              | Welcome, Mansarovar Park             |
+    | Mansarovar Park       | Shahdara, Jhilmil                    |
+    | Jhilmil               | Mansarovar Park, Dishad Garden       |
+    | Dilshad Garden        | Jhilmil                              |
+    +-----------------------+--------------------------------------+
+
+=over 2
+
+=item * The station "Inderlok" is also part of L<Green Line|Map::Tube::Delhi::Line::Green>.
+
+=item * The station "Kashmere Gate" is also part of L<Yellow Line|Map::Tube::Delhi::Line::Yellow>.
+
+=back
 
 =head1 AUTHOR
 
